@@ -1,7 +1,7 @@
 # This file is part of Hypothesis, which may be found at
 # https://github.com/HypothesisWorks/hypothesis/
 #
-# Most of this work is copyright (C) 2013-2020 David R. MacIver
+# Most of this work is copyright (C) 2013-2021 David R. MacIver
 # (david@drmaciver.com), but it contains contributions by others. See
 # CONTRIBUTING.rst for a full list of people who may hold copyright, and
 # consult the git log if you need to determine who owns an individual
@@ -45,8 +45,7 @@ def fulfill(contract_func):
     """
     if not hasattr(contract_func, "__contract_wrapped_func__"):
         raise InvalidArgument(
-            "There are no dpcontracts preconditions associated with %s"
-            % (contract_func.__name__,)
+            f"{contract_func.__name__} has no dpcontracts preconditions"
         )
 
     @proxies(contract_func)
